<?php
/**
 * Content Protector for WordPress. Exclusively on Envato Market: https://1.envato.market/42themeCC
 *
 * @encoding     UTF-8
 * @version      2.0.1
 * @copyright    Copyright (C) 2016-2023 42Theme (https://42theme.com). All rights reserved.
 * @license      Envato Standard Licenses
 * @author       Alexander Khmelnitskiy
 * @support      support@42theme.com
 **/

namespace T42\ContentProtector;

/** Exit if accessed directly. */
if ( ! defined( 'ABSPATH' ) ) {
    header( 'Status: 403 Forbidden' );
    header( 'HTTP/1.1 403 Forbidden' );
    exit;
}

/**
 * Controls class is responsible for initializing all the supported controls.
 *
 * @since 1.0.0
 * @author Alexander Khmelnitskiy
 **/
final class Controls {

    /**
     * Box shadow group control.
     *
     * @since 1.0.0
     * @var string
     **/
    const BOX_SHADOW = 'box_shadow';

    /**
     * Text input control.
     *
     * @since 1.0.0
     * @var string
     **/
    const TEXT = 'text';

    /**
     * Hidden input control.
     *
     * @since 1.0.0
     * @var string
     **/
    const HIDDEN = 'hidden';

    /**
     * Number input control.
     *
     * @since 1.0.0
     * @var string
     **/
    const NUMBER = 'number';

    /**
     * Number input with plus/minus buttons.
     *
     * @since 1.0.0
     * @var string
     **/
    const TOUCH_SPIN = 'touch_spin';

    /**
     * Heading + description control.
     *
     * @since 1.0.0
     * @var string
     **/
    const HEADER = 'header';

    /**
     * RAW HTML control.
     *
     * @since 1.0.0
     * @var string
     **/
    const HTML = 'html';

    /**
     * Button control.
     *
     * @since 1.0.0
     * @var string
     **/
    const BUTTON = 'button';

    /**
     * Button group control.
     *
     * @since 1.0.0
     * @var string
     **/
    const BUTTON_GROUP = 'button_group';

    /**
     * Radio toggle control.
     *
     * @since 1.0.0
     * @var string
     **/
    const RADIO_TOGGLE = 'radio_toggle';

    /**
     * Switcher true/false control.
     *
     * @since 1.0.0
     * @var string
     **/
    const SWITCHER = 'switcher';

    /**
     * Textarea control.
     *
     * @since 1.0.0
     * @var string
     **/
    const TEXTAREA = 'textarea';

    /**
     * Range slider control.
     *
     * @since 1.0.0
     * @var string
     **/
    const RANGE_SLIDER = 'range_slider';

    /**
     * Select control.
     *
     * @since 1.0.0
     * @var string
     **/
    const SELECT = 'select';

    /**
     * Colorpicker/Graident control.
     *
     * @since 1.0.0
     * @var string
     **/
    const COLORPICKER = 'colorpicker';

    /**
     * TinyMCE editor control.
     *
     * @since 1.0.0
     * @var string
     **/
    const EDITOR = 'editor';

    /**
     * Icon control.
     *
     * @since 1.0.0
     * @var string
     **/
    const ICON = 'icon';

    /**
     * Divider control.
     *
     * @since 1.0.0
     * @var string
     **/
    const DIVIDER = 'divider';

    /**
     * Custom control.
     *
     * @since 1.0.0
     * @var string
     **/
    const CUSTOM_TYPE = 'custom_type';

} // end Controls class.
