<?php
/**
 * Content Protector for WordPress. Exclusively on Envato Market: https://1.envato.market/42themeCC
 *
 * @encoding     UTF-8
 * @version      2.0.1
 * @copyright    Copyright (C) 2016-2023 42Theme (https://42theme.com). All rights reserved.
 * @license      Envato Standard Licenses
 * @author       Alexander Khmelnitskiy
 * @support      support@42theme.com
 **/

namespace T42\ContentProtector;

/** Exit if accessed directly. */
if ( ! defined( 'ABSPATH' ) ) {
    header( 'Status: 403 Forbidden' );
    header( 'HTTP/1.1 403 Forbidden' );
    exit;
}

/**
 * Factory class used to run additional tasks for different plugin types.
 *
 * @since 1.0.0
 * @author Alexander Khmelnitskiy
 **/
class PluginTypeFactory {

    /**
     * Creates a new PluginType instance based on the given type.
     *
     * @since 1.0.0
     * @access public
     *
     * @param string $type The plugin type.
     *
     * @return PluginType
     **/
    public static function createPlugin( $type ) {

        /** Build the class name by the given type. */
        $class = 'PluginType' . ucfirst( $type );

        /** Check if the class exists in the current namespace. */
        $class = __NAMESPACE__ . '\\' . $class;
        if ( ! class_exists( $class ) ) {
            $class = PluginTypePlugin::class; // Default to general WordPress plugin.
        }

        /** Return the new instance. */
        return new $class();

    }

}
