<?php
/**
 * Content Protector for WordPress. Exclusively on Envato Market: https://1.envato.market/42themeCC
 *
 * @encoding     UTF-8
 * @version      2.0.1
 * @copyright    Copyright (C) 2016-2023 42Theme (https://42theme.com). All rights reserved.
 * @license      Envato Standard Licenses
 * @author       Alexander Khmelnitskiy
 * @support      support@42theme.com
 **/

/** @noinspection PhpDocSignatureInspection */

namespace T42\ContentProtector;

/** Exit if accessed directly. */
if ( ! defined( 'ABSPATH' ) ) {
    header( 'Status: 403 Forbidden' );
    header( 'HTTP/1.1 403 Forbidden' );
    exit;
}

/**
 * Singleton Trait.
 *
 * @since 1.1.0
 * @author Alexander Khmelnitskiy
 **/
trait Singleton {

    /**
     * The one true [Class] instance.
     *
     * @since 1.1.0
     **/
    protected static $instance;

    /**
     * Reset [Class] Instance to null.
     *
     * @static
     * @since 1.1.0
     * @access public
     *
     * @return void
     **/
    public static function reset_instance() {

        static::$instance = null;

    }

    /**
     * Main [Class] Instance.
     *
     * Insures that only one instance of [Class] exists in memory at any one time.
     *
     * @static
     * @since 1.1.0
     * @access public
     *
     * @return [Class]
     **/
    public static function get_instance() {

        if ( ! isset( self::$instance ) && ! ( self::$instance instanceof self ) ) {
            self::$instance = new self;
        }

        return self::$instance;

    }

    /**
     * Create [Class] Instance if not exists.
     *
     * @static
     * @since 1.1.0
     * @access public
     *
     * @return void
     **/
    private static function create_instance() {

        if ( ! isset( self::$instance ) && ! ( self::$instance instanceof self ) ) {
            self::get_instance();
        }

    }

    private function __construct() {}

    /**
     * Throw error on object clone.
     *
     * The whole idea of the singleton design pattern is that there is a single
     * object therefore, we don't want the object to be cloned.
     *
     * @since 1.1.0
     * @access public
     *
     * @return void
     **/
    final public function __clone() {

        /** Cloning instances of the class is forbidden. */
        _doing_it_wrong( __FUNCTION__, esc_html__( 'The whole idea of the singleton design pattern is that there is a single object therefore, we don\'t want the object to be cloned.', 't42-content-protector' ), '2.0.1' );

    }

    /**
     * Disable unserializing of the class.
     *
     * The whole idea of the singleton design pattern is that there is a single
     * object therefore, we don't want the object to be unserialized.
     *
     * @since 1.1.0
     * @access public
     *
     * @return void
     **/
    final public function __wakeup() {

        /** Unserializing instances of the class is forbidden. */
        _doing_it_wrong( __FUNCTION__, esc_html__( 'The whole idea of the singleton design pattern is that there is a single object therefore, we don\'t want the object to be unserialized.', 't42-content-protector' ), '2.0.1' );

    }

} // End trait Singleton.