<?php
/**
 * Content Protector for WordPress. Exclusively on Envato Market: https://1.envato.market/42themeCC
 *
 * @encoding     UTF-8
 * @version      2.0.1
 * @copyright    Copyright (C) 2016-2023 42Theme (https://42theme.com). All rights reserved.
 * @license      Envato Standard Licenses
 * @author       Alexander Khmelnitskiy
 * @support      support@42theme.com
 **/

namespace T42\ContentProtector;

/** Exit if accessed directly. */
if ( ! defined( 'ABSPATH' ) ) {
    header( 'Status: 403 Forbidden' );
    header( 'HTTP/1.1 403 Forbidden' );
    exit;
}

/**
 * WidgetSubscribe class used to implement sidebar widget Subscribe.
 *
 * @since 1.0.0
 * @author Alexander Khmelnitskiy
 **/
final class WidgetSubscribe extends Widget {

    use Singleton;

    /**
     * Sets up a new WidgetSubscribe instance.
     *
     * @since 1.0.0
     * @access private
     *
     * @return void
     **/
    private function __construct() {

        $this->widget_id ='subscribe';
        $this->title = esc_html__( 'Subscribe', 't42-content-protector' );

    }

    /**
     * Render widget content.
     *
     * @since 1.0.0
     * @access private
     *
     * @return void
     **/
    protected function render_content() {

        /** Get subscriber name and email. */
        list( $name, $mail ) = Helper::get_instance()->get_current_user_details();

        ?>
        <div class="t42-card-body">
            <div class="t42-form-stacked t42-margin-large">
                <p>
                    <?php esc_html_e( 'Subscribe now and receive a box filled with hand-picked awesome items.', 't42-content-protector' ); ?>
                </p>

                <div class="t42-form-stacked">

                    <div class="t42-margin">
                        <div class="t42-inline t42-width-1-1">
                            <span class="t42-form-icon" t42-icon="icon: fi-user; ratio: 0.8"></span>
                            <input value="<?php esc_attr_e( $name ); ?>" class="t42-input t42-subscribe-name" type="text">
                        </div>
                    </div>

                    <div class="t42-margin">
                        <div class="t42-inline t42-width-1-1">
                            <span class="t42-form-icon" t42-icon="icon: fi-mail; ratio: 0.8"></span>
                            <input value="<?php esc_attr_e( $mail ); ?>" class="t42-input t42-subscribe-mail" placeholder="name@examle.com" type="email">
                        </div>
                        <div class="t42-margin-small-top t42-text-muted"><?php esc_html_e( 'We\'ll never share your email with anyone else.', 't42-content-protector' ); ?></div>
                    </div>

                    <div class="t42-margin-small-top">
                        <button class="t42-button t42-button-default t42-waves-effect t42-waves-light t42-subscribe-btn">Subscribe</button>
                    </div>

                </div>
            </div>
        </div>
        <?php

    }

} // End class WidgetSubscribe.
