/**
 * Content Protector for WordPress. Exclusively on Envato Market: https://1.envato.market/42themeCC
 *
 * @encoding     UTF-8
 * @version      2.0.1
 * @copyright    Copyright (C) 2016-2023 42Theme (https://42theme.com). All rights reserved.
 * @license      Envato Standard Licenses
 * @author       Alexander Khmelnitskiy
 * @support      support@42theme.com
 **/

( function ( $ ) {

    "use strict";

    /** Run as soon as the page DOM becomes safe to manipulate. */
    $( document ).ready( function () {

        /**
         * Search for our disabled plugins and add icons to them.
         *
         * @typedef {Object} t42PluginIconsReady
         *
         * @typedef {Object} t42ContentProtector
         * @property {string} pluginsURL
         **/
        function setPluginIconsForNeighbors() {

            /** Exit if another plugin already done this. */
            if ( window.t42PluginIconsReady ) { return; }

            /** Get all "our" inactive plugins. */
            let $plugins = $( '.inactive[data-plugin^="t42-"]' );

            /** For each plugin row, add an icon. */
            $plugins.each( function () {
                let $plugin = $( this );
                let pluginDir = $plugin.data( 'plugin' ).split( '/' )[0];
                let $pluginTitle = $plugin.find( '.plugin-title' );
                let pluginIcon = window.t42ContentProtector.pluginsURL + '/' + pluginDir + '/images/logo-color.svg';

                fetch( pluginIcon, { method: 'HEAD' } )
                    .then( res => {

                        /** Plugin Icon exists. */
                        if ( res.ok ) {
                            $pluginTitle.css('background-image', 'url("' + pluginIcon + '")');
                        }

                    } )
                    .catch( err => console.warn( 'Error:', err ) );

            } );

            /** Mark for other plugins that we already set the icons. */
            window.t42PluginIconsReady = true;

        }
        setPluginIconsForNeighbors();

    } );

} ( jQuery ) );